pub mod login;
pub mod game_actions;
pub mod map_actions;

use game_actions::SpawnToken;
use serde::{Deserialize, Serialize};

use crate::game::{chat_message::ChatMessage, entry::ActionResult};

#[derive(Serialize, Deserialize, Default, Debug)]
#[serde(rename_all = "snake_case")]
pub enum Request {
    #[default]
    Error,
    // Connection requests 
    Login(login::LoginRequest),
    Quit,
    Kick(String),
    Shutdown,
    // Chat requests
    Message(ChatMessage),
    GetChatHistory { amount: usize, from: usize },
    GetLastMessages { amount: usize, },
    // Map requests
    GetTokens,
    SpawnToken { x: i32, y: i32, img_path: String },
    MoveToken { token_id: usize, x: i32, y: i32 },
    // Actions requests
    ActionResult(ActionResult)
}
#[derive(Serialize, Clone, Debug)]
#[serde(rename_all = "snake_case")]
pub enum Response {
    Error(RequestError),
    Login(login::LoginResult),
    Message(ChatMessage),
    GetChatHistory(Vec<ChatMessage>),
    MoveToken { token_id: usize, x: i32, y: i32 },
    SpawnToken(SpawnToken),
    Quit { id: String },
    Shutdown,

}

#[derive(Serialize, Debug, Clone)]
#[serde(rename_all = "snake_case")]
pub enum RequestError {
    InvalidRequest,
    AlreadyLoggedIn,
}